"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CmsEntriesDataSource = void 0;
var _zod = _interopRequireDefault(require("zod"));
var _ModelListQuery = require("./ModelListQuery");
class CmsEntriesDataSource {
  constructor(cms) {
    this.cms = cms;
  }
  getType() {
    return "cms.entries";
  }
  getConfigSchema() {
    return _zod.default.object({
      modelId: _zod.default.string(),
      limit: _zod.default.number()
    });
  }
  async load(request) {
    const requestedPaths = request.getPaths();
    const queryPaths = !requestedPaths || requestedPaths.length === 0 ? ["id"] : requestedPaths;
    const config = request.getConfig();
    const schemaClient = await this.cms.getExecutableSchema("preview");
    const model = await this.cms.getModel(config.modelId);
    const listQuery = new _ModelListQuery.ModelListQuery();
    const query = listQuery.getQuery(model, queryPaths);
    const response = await schemaClient({
      query,
      operationName: "ListEntries",
      variables: {
        limit: config.limit || 10
      }
    });

    // @ts-expect-error Naive return for the time being.
    return response.data.entries.data;
  }
}
exports.CmsEntriesDataSource = CmsEntriesDataSource;

//# sourceMappingURL=CmsEntriesDataSource.js.map